@@ -11,9 +11,9 @@
 
 G_BEGIN_DECLS
 
-#define SOUP_MAJOR_VERSION (2)
-#define SOUP_MINOR_VERSION (99)
-#define SOUP_MICRO_VERSION (8)
+#define SOUP_MAJOR_VERSION (3)
+#define SOUP_MINOR_VERSION (0)
+#define SOUP_MICRO_VERSION (6)
 
 #define SOUP_CHECK_VERSION(major, minor, micro) \
     (SOUP_MAJOR_VERSION > (major) || \
@@ -32,7 +32,7 @@ G_BEGIN_DECLS
 #  ifdef G_PLATFORM_WIN32
 #    ifdef LIBSOUP_COMPILATION
 #      ifdef DLL_EXPORT
-#        define SOUP_VAR __declspec(dllexport)
+#        define SOUP_VAR extern __declspec(dllexport)
 #      else /* !DLL_EXPORT */
 #        define SOUP_VAR extern
 #      endif /* !DLL_EXPORT */
@@ -61,20 +61,21 @@ G_BEGIN_DECLS
  * this means the next stable target
  */
 #if (SOUP_MINOR_VERSION % 2)
-#if (SOUP_MAJOR_VERSION == 2)
-#define SOUP_VERSION_CUR_STABLE (G_ENCODE_VERSION (3, 0))
-#else
 #define SOUP_VERSION_CUR_STABLE (G_ENCODE_VERSION (SOUP_MAJOR_VERSION, SOUP_MINOR_VERSION + 1))
-#endif
 #else
 #define SOUP_VERSION_CUR_STABLE (G_ENCODE_VERSION (SOUP_MAJOR_VERSION, SOUP_MINOR_VERSION))
 #endif
 
 /* evaluates to the previous stable version */
-#if (SOUP_MINOR_VERSION % 2)
-#define SOUP_VERSION_PREV_STABLE (G_ENCODE_VERSION (SOUP_MAJOR_VERSION, SOUP_MINOR_VERSION - 1))
+#if (SOUP_MINOR_VERSION == 0)
+/* Can't have -1 for previous version */
+# define SOUP_VERSION_PREV_STABLE (G_ENCODE_VERSION (SOUP_MAJOR_VERSION, 0))
 #else
-#define SOUP_VERSION_PREV_STABLE (G_ENCODE_VERSION (SOUP_MAJOR_VERSION, SOUP_MINOR_VERSION - 2))
+# if (SOUP_MINOR_VERSION % 2)
+#  define SOUP_VERSION_PREV_STABLE (G_ENCODE_VERSION (SOUP_MAJOR_VERSION, SOUP_MINOR_VERSION - 1))
+# else
+#  define SOUP_VERSION_PREV_STABLE (G_ENCODE_VERSION (SOUP_MAJOR_VERSION, SOUP_MINOR_VERSION - 2))
+# endif
 #endif
 
 #ifndef SOUP_VERSION_MIN_REQUIRED
